
import { lazy, Suspense } from 'react';
import Header from '@/components/Header';
import EnhancedBreadcrumbs from '@/components/EnhancedBreadcrumbs';
import SEOHead from '@/components/SEOHead';
import MobileOptimizedHero from '@/components/MobileOptimizedHero';
import { InlineCriticalCSS } from '@/components/CriticalCSSInline';
import LightweightLoader from '@/components/LightweightLoader';
import Footer from '@/components/Footer';
import SEOFooterLinks from '@/components/SEOFooterLinks';
import WhoLoansFor from '@/components/WhoLoansFor';
import LoanEditions from '@/components/LoanEditions';
import Resources from '@/components/Resources';
import FAQ from '@/components/FAQ';
import SuccessStories from '@/components/SuccessStories';
import OptimizedContactSection from '@/components/OptimizedContactSection';
import { useIsMobile } from '@/hooks/use-mobile';

// Only lazy load truly heavy components
const LazySection = lazy(() => import('@/components/LazySection').then(m => ({ default: m.LazySection })));
const USMapSection = lazy(() => import('@/components/USMapSection'));
const OptimizedMortgageCalculator = lazy(() => import('@/components/OptimizedMortgageCalculator'));
const PartnerToolkit = lazy(() => import('@/components/PartnerToolkit'));
const AIChat = lazy(() => import('@/components/AIChat'));
const DeferredWidgets = lazy(() => import('@/components/DeferredWidgets'));
const SEOInternalLinks = lazy(() => import('@/components/SEOInternalLinks'));
import { Separator } from '@/components/ui/separator';

const Index = () => {
  const isMobile = useIsMobile();

  return (
    <div className="min-h-screen bg-brand-off-white overflow-x-hidden">
      <InlineCriticalCSS />
      <SEOHead
        title="Zero Income Mortgage - Bank Statement & Non-QM Loans for Self-Employed"
        description="Get approved for bank statement loans, DSCR loans, and no-doc mortgages. Specialized non-QM lending for self-employed borrowers, real estate investors, and alternative income verification."
      />
      <Header />
      <EnhancedBreadcrumbs />
      <main className="relative">
        <MobileOptimizedHero />
        
        {/* Strategic SEO links after hero section */}
        <div className="container mx-auto px-4 py-4">
          <div className="max-w-4xl mx-auto text-center">
            <p className="text-gray-600 text-sm mobile-text-center">
              Explore our comprehensive <Suspense fallback={<span>services</span>}><SEOInternalLinks pageType="homepage" /></Suspense> to find the perfect mortgage solution for your unique financial situation.
            </p>
          </div>
        </div>
        
        <WhoLoansFor />
        <LoanEditions />
        
        {/* SEO links after loan programs */}
        <div className="container mx-auto px-4 py-4">
          <div className="max-w-4xl mx-auto text-center">
            <p className="text-gray-600 text-sm mobile-text-center">
              Ready to get started? <Suspense fallback={<span>Contact us</span>}><SEOInternalLinks pageType="loan-program" /></Suspense> or learn more about our specialized lending programs.
            </p>
          </div>
        </div>
        
        {/* Only load heavy components on desktop for better mobile performance */}
        {!isMobile && (
          <Suspense fallback={<LightweightLoader />}>
            <LazySection>
              <USMapSection />
            </LazySection>
            
            <LazySection>
              <OptimizedMortgageCalculator />
            </LazySection>
            
            <LazySection>
              <PartnerToolkit />
            </LazySection>
          </Suspense>
        )}
        
        <Resources />
        <FAQ />
        <SuccessStories />
        <OptimizedContactSection />
        
        <Suspense fallback={<LightweightLoader />}>
          <LazySection>
            <AIChat />
          </LazySection>
        </Suspense>
      </main>
      
      <SEOFooterLinks />
      <Footer />
      
      <Suspense fallback={null}>
        <DeferredWidgets />
      </Suspense>
    </div>
  );
};

export default Index;
